<html>

<style>
  a {
    width: 100%;
  }
</style>

<body>

<div class="row">
  <div class="col-md-4 col-md-offset-4">
    <h1>Scorpion User Study</h1>

    <h2>Tutorial Section</h2>
    <p><a href="/1/" class='btn btn-primary'>Basic Tutorial</a></p>
    <p><a href="/2/" class='btn btn-primary'>Verification Tasks</a></p>
    <p><a href="/3/" class='btn btn-primary'>Scorpion Tutorial</a></p>

    <!--
    <h2>User Study</h2>
    <p><a href="/4/" class='btn btn-primary'>Study 1</a></p>
    -->


  </div>
</div>

{% include 'footer.html' %}

</body>

	<link rel="stylesheet" type="text/css" href="/static/css/bootstrap.min.css"/>
	<link rel="stylesheet" type="text/css" href="/static/css/base.css"/>
</html>
